@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Awb0SavedBookmark, Awb0ProductContextInfo
+from tcsoa.gen.BusinessObjects import Awb0ProductContextInfo, Awb0SavedBookmark
 from typing import List
-from tcsoa.gen.ActiveWorkspaceBom._2015_10.OccurrenceManagementCad import ProductContextBOMWindowResponse, SavedBookmarksBOMWindowsResponse
-from tcsoa.utils import TcService
+from tcsoa.gen.ActiveWorkspaceBom._2015_10.OccurrenceManagementCad import SavedBookmarksBOMWindowsResponse, ProductContextBOMWindowResponse
+from tcsoa.base import TcService
 
 
 class OccurrenceManagementCadService(TcService):
