@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import Group, Role
 from typing import List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
