@@ -4,7 +4,7 @@ from tcsoa.gen.BusinessModeler._2008_06.services import DeepCopyRulesService as
 from tcsoa.gen.BusinessModeler._2007_06.services import ConstantsService as imp3
 from tcsoa.gen.BusinessModeler._2011_06.services import ConstantsService as imp4
 from tcsoa.gen.BusinessModeler._2010_04.services import BusinessRulesService as imp5
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ConditionEngineService(TcService):
