@@ -70,7 +70,7 @@ from tcsoa.gen.Core._2009_04.services import SessionService as imp68
 from tcsoa.gen.Core._2008_06.services import ReservationService as imp69
 from tcsoa.gen.Core._2019_06.services import DataManagementService as imp70
 from tcsoa.gen.Core._2008_05.services import DataManagementService as imp71
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
