@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import ListOfValues, BusinessObject
+from tcsoa.gen.BusinessObjects import BusinessObject, ListOfValues
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
