@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Awp0AdvancedSearchInput, Awp0AdvancedQueryCriteria
+from tcsoa.gen.BusinessObjects import Awp0AdvancedQueryCriteria, Awp0AdvancedSearchInput
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
