@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import ItemRevision, BusinessObject, ImanFile, Dataset
+from tcsoa.gen.BusinessObjects import BusinessObject, ImanFile, ItemRevision, Dataset
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
