@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class CodeCoverageManagementService(TcService):
