@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_ConfigFilterCriteria._2013_12.services import VariantManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class VariantManagementService(TcService):
