@@ -3,7 +3,7 @@ from tcsoa.gen.Internal_DocumentManagement._2008_06.services import DispatcherMa
 from tcsoa.gen.Internal_DocumentManagement._2008_06.services import DocumentControlService as imp2
 from tcsoa.gen.Internal_DocumentManagement._2013_12.services import MarkupService as imp3
 from tcsoa.gen.Internal_DocumentManagement._2020_12.services import AttributeExchangeService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DigitalSignatureService(TcService):
