@@ -4,7 +4,7 @@ from tcsoa.gen.Internal_IcsAw._2018_12.services import ClassificationService as
 from tcsoa.gen.Internal_IcsAw._2019_12.services import ClassificationService as imp3
 from tcsoa.gen.Internal_IcsAw._2017_12.services import AuthorService as imp4
 from tcsoa.gen.Internal_IcsAw._2019_06.services import ClassificationService as imp5
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AuthorService(TcService):
