@@ -2,7 +2,7 @@ from tcsoa.gen.Internal_ImportExport._2010_04.services import L10NImportExportSe
 from tcsoa.gen.Internal_ImportExport._2018_06.services import L10NImportExportService as imp1
 from tcsoa.gen.Internal_ImportExport._2017_11.services import FileImportExportService as imp2
 from tcsoa.gen.Internal_ImportExport._2017_05.services import FileImportExportService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class L10NImportExportService(TcService):
