@@ -2,7 +2,7 @@ from tcsoa.gen.Internal_Multisite._2017_11.services import ArchiveRestoreService
 from tcsoa.gen.Internal_Multisite._2018_06.services import SearchService as imp1
 from tcsoa.gen.Internal_Multisite._2020_12.services import ImportExportTCXMLService as imp2
 from tcsoa.gen.Internal_Multisite._2011_06.services import ImportExportAsyncService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ArchiveRestoreService(TcService):
