@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Reports._2007_06.BOMRollup import RollupTemplateResponse, CreateRollupTemplateInput, RollupTemplateCalculationResponse, ReviseRollupReportInput, RollupTemplateInput, CreateRollupCalculationTemplateResponse, RollupReportResponse, GetRollupTemplateInput, CreateRollupReportInput, CreateRollupCalculationTemplateInput
+from tcsoa.gen.Internal.Reports._2007_06.BOMRollup import CreateRollupTemplateInput, RollupReportResponse, GetRollupTemplateInput, RollupTemplateInput, RollupTemplateCalculationResponse, ReviseRollupReportInput, CreateRollupCalculationTemplateInput, RollupTemplateResponse, CreateRollupCalculationTemplateResponse, CreateRollupReportInput
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class BOMRollupService(TcService):
