@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_UiConfig._2014_11.services import UiConfigService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class UiConfigService(TcService):
