@@ -2,7 +2,7 @@ from tcsoa.gen.Internal_Validation._2007_06.services import ValidationService as
 from tcsoa.gen.Internal_Validation._2012_02.services import ValidationService as imp1
 from tcsoa.gen.Internal_Validation._2008_06.services import ValidationService as imp2
 from tcsoa.gen.Internal_Validation._2010_04.services import ValidationService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ValidationService(TcService):
