@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_XlsBom._2020_12.services import ImportService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ImportService(TcService):
