@@ -3,7 +3,7 @@ from tcsoa.gen.Multisite._2011_06.services import ImportExportService as imp1
 from tcsoa.gen.Multisite._2019_06.services import ImportExportTCXMLService as imp2
 from tcsoa.gen.Multisite._2014_10.services import ImportExportTCXMLService as imp3
 from tcsoa.gen.Multisite._2007_06.services import ImportExportService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SearchService(TcService):
