@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, ImanActionHandler, ImanSubscription, Condition, User, ImanEventType
+from tcsoa.gen.BusinessObjects import BusinessObject, ImanSubscription, ImanEventType, Condition, User, ImanActionHandler
 from enum import Enum
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
