@@ -1,5 +1,5 @@
 from tcsoa.gen.Participant._2018_11.services import ParticipantService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ParticipantService(TcService):
