@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.Qualification._2014_06.QualificationManagement import AssignUserQualificationInfo, QualificationLevelInfo, ManageQualificationInfo, UpdateQualificationInfo, RemoveUserQualificationInfo
+from tcsoa.gen.Qualification._2014_06.QualificationManagement import QualificationLevelInfo, ManageQualificationInfo, RemoveUserQualificationInfo, UpdateQualificationInfo, AssignUserQualificationInfo
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class QualificationManagementService(TcService):
